"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.maskingPrint = exports.BaseModel = exports.nanoid = void 0;
const cm_libs_context_aware_logger_1 = require("cm-libs-context-aware-logger");
const nanoid_1 = require("nanoid");
Object.defineProperty(exports, "nanoid", { enumerable: true, get: function () { return nanoid_1.nanoid; } });
var RecordStatus;
(function (RecordStatus) {
    RecordStatus["ACTIVE"] = "ACTIVE";
    RecordStatus["INACTIVE"] = "INACTIVE";
})(RecordStatus || (RecordStatus = {}));
class BaseModel {
    constructor(prisma, formatErrorHandler, modelName = 'BaseModel') {
        this.modelName = 'BaseModel';
        this.prisma = prisma;
        this.modelName = modelName;
        this.formatErrorHandler = formatErrorHandler;
    }
    async add(input, requestedBy) {
        const logHeader = `[${this.modelName}-add]`;
        try {
            const now = new Date(new Date().toUTCString());
            const data = {
                uuid: (0, nanoid_1.nanoid)(),
                createdBy: requestedBy,
                createdAt: now,
                updatedBy: requestedBy,
                updatedAt: now,
                ...input
            };
            const dbData = await this.prisma.create({ data: data });
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
    async read(where) {
        const logHeader = `[${this.modelName}-read]`;
        try {
            const dbData = await this.prisma.findUnique({
                where
            });
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
    async browse(pagination, where, scanAll = false) {
        const logHeader = `[${this.modelName}-browse]`;
        try {
            pagination ??= {};
            pagination.page ??= 1;
            pagination.pageSize ??= 10;
            where = {
                status: RecordStatus.ACTIVE,
                ...where
            };
            // where.status ??= RecordStatus.ACTIVE
            const skip = (pagination.page - 1) * pagination.pageSize;
            if (pagination.pageSize === 0 && scanAll !== true) {
                scanAll = true;
            }
            const count = await this.prisma.count({ where });
            const dbData = {
                items: scanAll
                    ? await this.prisma.findMany({ orderBy: [{ createdAt: 'asc' }], where })
                    : await this.prisma.findMany({ orderBy: [{ createdAt: 'asc' }], take: pagination.pageSize, skip, where }),
                properties: { ...pagination, count }
            };
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
    async edit(input, requestedBy) {
        const logHeader = `[${this.modelName}-edit]`;
        try {
            const uuid = input['uuid'];
            delete input['uuid'];
            const data = { ...input, updatedBy: requestedBy };
            const where = { uuid };
            const dbData = await this.prisma.update({ where: where, data });
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
    async delete(where) {
        const logHeader = `[${this.modelName}-delete]`;
        try {
            const dbData = await this.prisma.delete({ where });
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
    async deactivateByUuid(uuid, requestedBy) {
        const logHeader = `[${this.modelName}-deactivateByUuid]`;
        try {
            const data = {
                uuid,
                status: RecordStatus.INACTIVE,
                updatedBy: requestedBy
            };
            const dbData = this.edit(data, requestedBy);
            (0, cm_libs_context_aware_logger_1.log)(cm_libs_context_aware_logger_1.Level.DEBUG, () => `${logHeader} dbData:${JSON.stringify(maskingPrint(dbData))}`);
            return dbData;
        }
        catch (error) {
            this.formatErrorHandler(error, logHeader);
        }
    }
}
exports.BaseModel = BaseModel;
function maskingPrint(json) {
    if (!json)
        return '';
    Object.keys(json).forEach(async function (key) {
        if (key === 'systemLog' || key === 'kernelLog' || key === 'metricsFile') {
            json[key] = '[Masked Value!!!]';
        }
    });
    return json;
}
exports.maskingPrint = maskingPrint;
//# sourceMappingURL=model.js.map